@@ -275,7 +275,7 @@ class Elasticsearch(object):
         """
         Returns whether the cluster is running.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/index.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/index.html>`_
         """
         try:
             return self.transport.perform_request(
@@ -289,7 +289,7 @@ class Elasticsearch(object):
         """
         Returns basic information about the cluster.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/index.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/index.html>`_
         """
         return self.transport.perform_request(
             "GET", "/", params=params, headers=headers
@@ -309,7 +309,7 @@ class Elasticsearch(object):
         Creates a new document in the index.  Returns a 409 response when a document
         with a same ID already exists in the index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/docs-index_.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/docs-index_.html>`_
 
         :arg index: The name of the index
         :arg id: Document ID
@@ -362,7 +362,7 @@ class Elasticsearch(object):
         """
         Creates or updates a document in an index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/docs-index_.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/docs-index_.html>`_
 
         :arg index: The name of the index
         :arg body: The document
@@ -426,7 +426,7 @@ class Elasticsearch(object):
         """
         Allows to perform multiple index/update/delete operations in a single request.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/docs-bulk.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/docs-bulk.html>`_
 
         :arg body: The operation definition and data (action-data
             pairs), separated by newlines
@@ -473,7 +473,7 @@ class Elasticsearch(object):
         """
         Explicitly clears the search context for a scroll.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/clear-scroll-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/clear-scroll-api.html>`_
 
         :arg body: A comma-separated list of scroll IDs to clear if none
             was specified via the scroll_id parameter
@@ -510,7 +510,7 @@ class Elasticsearch(object):
         """
         Returns number of documents matching a query.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/search-count.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/search-count.html>`_
 
         :arg body: A query to restrict the results specified with the
             Query DSL (optional)
@@ -568,7 +568,7 @@ class Elasticsearch(object):
         """
         Removes a document from the index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/docs-delete.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/docs-delete.html>`_
 
         :arg index: The name of the index
         :arg id: The document ID
@@ -644,7 +644,7 @@ class Elasticsearch(object):
         """
         Deletes documents matching the provided query.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/docs-delete-by-query.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/docs-delete-by-query.html>`_
 
         :arg index: A comma-separated list of index names to search; use
             `_all` or empty string to perform the operation on all indices
@@ -741,7 +741,7 @@ class Elasticsearch(object):
         Changes the number of requests per second for a particular Delete By Query
         operation.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/docs-delete-by-query.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/docs-delete-by-query.html>`_
 
         :arg task_id: The task id to rethrottle
         :arg requests_per_second: The throttle to set on this request in
@@ -762,7 +762,7 @@ class Elasticsearch(object):
         """
         Deletes a script.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/modules-scripting.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/modules-scripting.html>`_
 
         :arg id: Script ID
         :arg master_timeout: Specify timeout for connection to master
@@ -791,7 +791,7 @@ class Elasticsearch(object):
         """
         Returns information about whether a document exists in an index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/docs-get.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/docs-get.html>`_
 
         :arg index: The name of the index
         :arg id: The document ID
@@ -842,7 +842,7 @@ class Elasticsearch(object):
         """
         Returns information about whether a document source exists in an index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/docs-get.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/docs-get.html>`_
 
         :arg index: The name of the index
         :arg id: The document ID
@@ -896,7 +896,7 @@ class Elasticsearch(object):
         """
         Returns information about why a specific matches (or doesn't match) a query.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/search-explain.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/search-explain.html>`_
 
         :arg index: The name of the index
         :arg id: The document ID
@@ -949,7 +949,7 @@ class Elasticsearch(object):
         Returns the information about the capabilities of fields among multiple
         indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/search-field-caps.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/search-field-caps.html>`_
 
         :arg body: An index filter specified with the Query DSL
         :arg index: A comma-separated list of index names; use `_all` or
@@ -990,7 +990,7 @@ class Elasticsearch(object):
         """
         Returns a document.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/docs-get.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/docs-get.html>`_
 
         :arg index: The name of the index
         :arg id: The document ID
@@ -1031,7 +1031,7 @@ class Elasticsearch(object):
         """
         Returns a script.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/modules-scripting.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/modules-scripting.html>`_
 
         :arg id: Script ID
         :arg master_timeout: Specify timeout for connection to master
@@ -1058,7 +1058,7 @@ class Elasticsearch(object):
         """
         Returns the source of a document.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/docs-get.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/docs-get.html>`_
 
         :arg index: The name of the index
         :arg id: The document ID
@@ -1108,7 +1108,7 @@ class Elasticsearch(object):
         """
         Allows to get multiple documents in one request.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/docs-multi-get.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/docs-multi-get.html>`_
 
         :arg body: Document identifiers; can be either `docs`
             (containing full document information) or `ids` (when index and type is
@@ -1155,7 +1155,7 @@ class Elasticsearch(object):
         """
         Allows to execute several search operations in one request.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/search-multi-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/search-multi-search.html>`_
 
         :arg body: The request definitions (metadata-search request
             definition pairs), separated by newlines
@@ -1182,8 +1182,7 @@ class Elasticsearch(object):
         :arg rest_total_hits_as_int: Indicates whether hits.total should
             be rendered as an integer or an object in the rest search response
         :arg search_type: Search operation type  Valid choices:
-            query_then_fetch, query_and_fetch, dfs_query_then_fetch,
-            dfs_query_and_fetch
+            query_then_fetch, dfs_query_then_fetch
         :arg typed_keys: Specify whether aggregation and suggester names
             should be prefixed by their respective types in the response
         """
@@ -1212,7 +1211,7 @@ class Elasticsearch(object):
         """
         Allows to execute several search template operations in one request.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/search-multi-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/search-multi-search.html>`_
 
         :arg body: The request definitions (metadata-search request
             definition pairs), separated by newlines
@@ -1228,8 +1227,7 @@ class Elasticsearch(object):
         :arg rest_total_hits_as_int: Indicates whether hits.total should
             be rendered as an integer or an object in the rest search response
         :arg search_type: Search operation type  Valid choices:
-            query_then_fetch, query_and_fetch, dfs_query_then_fetch,
-            dfs_query_and_fetch
+            query_then_fetch, dfs_query_then_fetch
         :arg typed_keys: Specify whether aggregation and suggester names
             should be prefixed by their respective types in the response
         """
@@ -1265,7 +1263,7 @@ class Elasticsearch(object):
         """
         Returns multiple termvectors in one request.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/docs-multi-termvectors.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/docs-multi-termvectors.html>`_
 
         :arg body: Define ids, documents, parameters or a list of
             parameters per document here. You must at least provide a list of
@@ -1318,7 +1316,7 @@ class Elasticsearch(object):
         """
         Creates or updates a script.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/modules-scripting.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/modules-scripting.html>`_
 
         :arg id: Script ID
         :arg body: The document
@@ -1346,7 +1344,7 @@ class Elasticsearch(object):
         Allows to evaluate the quality of ranked search results over a set of typical
         search queries
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/search-rank-eval.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/search-rank-eval.html>`_
 
         .. warning::
 
@@ -1395,7 +1393,7 @@ class Elasticsearch(object):
         source documents by a query, changing the destination index settings, or
         fetching the documents from a remote cluster.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/docs-reindex.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/docs-reindex.html>`_
 
         :arg body: The search definition using the Query DSL and the
             prototype for the index request.
@@ -1431,7 +1429,7 @@ class Elasticsearch(object):
         """
         Changes the number of requests per second for a particular Reindex operation.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/docs-reindex.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/docs-reindex.html>`_
 
         :arg task_id: The task id to rethrottle
         :arg requests_per_second: The throttle to set on this request in
@@ -1452,7 +1450,7 @@ class Elasticsearch(object):
         """
         Allows to use the Mustache language to pre-render a search definition.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/search-template.html#_validating_templates>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/render-search-template-api.html>`_
 
         :arg body: The search definition template and its params
         :arg id: The id of the stored search template
@@ -1492,7 +1490,7 @@ class Elasticsearch(object):
         """
         Allows to retrieve a large numbers of results from a single search request.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/search-request-body.html#request-body-search-scroll>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/search-request-body.html#request-body-search-scroll>`_
 
         :arg body: The scroll ID if not passed by URL or query
             parameter.
@@ -1562,7 +1560,7 @@ class Elasticsearch(object):
         """
         Returns results matching a query.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/search-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/search-search.html>`_
 
         :arg body: The search definition using the Query DSL
         :arg index: A comma-separated list of index names to search; use
@@ -1688,7 +1686,7 @@ class Elasticsearch(object):
         Returns information about the indices and shards that a search request would be
         executed against.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/search-shards.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/search-shards.html>`_
 
         :arg index: A comma-separated list of index names to search; use
             `_all` or empty string to perform the operation on all indices
@@ -1731,7 +1729,7 @@ class Elasticsearch(object):
         """
         Allows to use the Mustache language to pre-render a search definition.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/search-template.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/search-template.html>`_
 
         :arg body: The search definition template and its params
         :arg index: A comma-separated list of index names to search; use
@@ -1762,8 +1760,7 @@ class Elasticsearch(object):
         :arg scroll: Specify how long a consistent view of the index
             should be maintained for scrolled search
         :arg search_type: Search operation type  Valid choices:
-            query_then_fetch, query_and_fetch, dfs_query_then_fetch,
-            dfs_query_and_fetch
+            query_then_fetch, dfs_query_then_fetch
         :arg typed_keys: Specify whether aggregation and suggester names
             should be prefixed by their respective types in the response
         """
@@ -1798,7 +1795,7 @@ class Elasticsearch(object):
         Returns information and statistics about terms in the fields of a particular
         document.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/docs-termvectors.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/docs-termvectors.html>`_
 
         :arg index: The index in which the document resides.
         :arg body: Define parameters and or supply a document to get
@@ -1857,7 +1854,7 @@ class Elasticsearch(object):
         """
         Updates a document with a script or partial document.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/docs-update.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/docs-update.html>`_
 
         :arg index: The name of the index
         :arg id: Document ID
@@ -1950,7 +1947,7 @@ class Elasticsearch(object):
         Performs an update on every document in the index without changing the source,
         for example to pick up a mapping change.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/docs-update-by-query.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/docs-update-by-query.html>`_
 
         :arg index: A comma-separated list of index names to search; use
             `_all` or empty string to perform the operation on all indices
@@ -2050,7 +2047,7 @@ class Elasticsearch(object):
         Changes the number of requests per second for a particular Update By Query
         operation.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/docs-update-by-query.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/docs-update-by-query.html>`_
 
         :arg task_id: The task id to rethrottle
         :arg requests_per_second: The throttle to set on this request in
@@ -2087,7 +2084,7 @@ class Elasticsearch(object):
         """
         Returns available script types, languages and contexts
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/modules-scripting.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/modules-scripting.html>`_
 
         .. warning::
 
@@ -2103,7 +2100,7 @@ class Elasticsearch(object):
         """
         Close a point in time
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/point-in-time-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/point-in-time-api.html>`_
 
         :arg body: a point-in-time id to close
         """
@@ -2118,7 +2115,7 @@ class Elasticsearch(object):
         """
         Open a point in time that can be used in subsequent searches
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/point-in-time-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/point-in-time-api.html>`_
 
         :arg index: A comma-separated list of index names to open point
             in time; use `_all` or empty string to perform the operation on all
@@ -2136,3 +2133,33 @@ class Elasticsearch(object):
         return self.transport.perform_request(
             "POST", _make_path(index, "_pit"), params=params, headers=headers
         )
+
+    @query_params()
+    def terms_enum(self, index, body=None, params=None, headers=None):
+        """
+        The terms enum API  can be used to discover terms in the index that begin with
+        the provided string. It is designed for low-latency look-ups used in auto-
+        complete scenarios.
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/search-terms-enum.html>`_
+
+        .. warning::
+
+            This API is **beta** so may include breaking changes
+            or be removed in a future version
+
+        :arg index: A comma-separated list of index names to search; use
+            `_all` or empty string to perform the operation on all indices
+        :arg body: field name, string which is the prefix expected in
+            matching terms, timeout and size for max number of results
+        """
+        if index in SKIP_IN_PATH:
+            raise ValueError("Empty value passed for a required argument 'index'.")
+
+        return self.transport.perform_request(
+            "POST",
+            _make_path(index, "_terms_enum"),
+            params=params,
+            headers=headers,
+            body=body,
+        )
